%define anolis_release 2

%global pypi_name autobahn

Name:           python-%{pypi_name}
Version:        23.6.2
Release:        %{anolis_release}%{?dist}
Summary:        Python networking library for WebSocket and WAMP

License:        MIT
URL:            https://autobahn.readthedocs.io/en/latest/
Source0:        https://github.com/crossbario/autobahn-python/archive/v%{version}/%{pypi_name}-%{version}.tar.gz
BuildArch:      noarch

%description
Autobahn a networking library that is part of the Autobahn project and provides
implementations of
* The WebSocket Protocol http://tools.ietf.org/html/rfc6455_
* The Web Application Messaging Protocol (WAMP) http://wamp.ws
for Twisted and for writing servers and clients.

%package -n     python3-%{pypi_name}
Summary:        %{summary}

BuildRequires:  python3-devel
BuildRequires:  %py3_dist setuptools
BuildRequires:  %py3_dist argon2_cffi
BuildRequires:  %py3_dist cffi
BuildRequires:  %py3_dist passlib
BuildRequires:  %py3_dist pytest
BuildRequires:  %py3_dist pytest-asyncio
BuildRequires:  %py3_dist six
BuildRequires:  %py3_dist twisted
BuildRequires:  %py3_dist txaio
BuildRequires:  %py3_dist pynacl
BuildRequires:  %py3_dist cbor2
BuildRequires:  %py3_dist cryptography
BuildRequires:  %py3_dist hyperlink
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
Autobahn a networking library that is part of the Autobahn project and provides
implementations of
* The WebSocket Protocol http://tools.ietf.org/html/rfc6455_
* The Web Application Messaging Protocol (WAMP) http://wamp.ws
for Twisted and for writing servers and clients.

%package -n python3-%{pypi_name}-doc
Summary:        Documentation for %{name}

BuildRequires:  %py3_dist sphinx
BuildRequires:  %py3_dist sphinx-rtd-theme
#BuildRequires:  %%py3_dist sphinxcontrib.images
%description -n python3-%{pypi_name}-doc
Documentation for %{name}.

%{?python_extras_subpkg:%python_extras_subpkg -n python3-%{pypi_name} -i %{python3_sitelib}/%{pypi_name}-%{version}*-py%{python3_version}.egg-info twisted}

%prep
%autosetup -n %{pypi_name}-python-%{version}
rm -rf %{pypi_name}.egg-info
# There is a requirement for pytest 6.2+ in pytest.ini and we don't have that yet
# it works with 6.0 just fine and the config file is not needed
rm pytest.ini
# Some packages are always outdated...
sed -i -e "s/cryptography>=3.4.6/cryptography>=3.4.2/g" setup.py
# Remove packages that will try to import attrs (optionnal deps) since in EPEL it's outdated and doesn't allow the import of attrs
# See https://www.attrs.org/en/stable/changelog.html#id11

%build
# Disable in case local builder support NVX
AUTOBAHN_USE_NVX=false %py3_build

%install
AUTOBAHN_USE_NVX=false %py3_install

%check
USE_ASYNCIO=1 %pytest --pyargs autobahn -k 'not test_no_memory_arg and not test_basic and not test_websocket_custom_loop and not TestSerializer'

%files -n python3-%{pypi_name}
%license LICENSE
%{_bindir}/wamp
%{_bindir}/xbrnetwork
%{_bindir}/xbrnetwork-ui
%{python3_sitelib}/%{pypi_name}-%{version}*-py%{python3_version}.egg-info/
%{python3_sitelib}/%{pypi_name}/
%dir %{python3_sitelib}/twisted
%dir %{python3_sitelib}/twisted/plugins
%dir %{python3_sitelib}/twisted/plugins/__pycache__
%{python3_sitelib}/twisted/plugins/autobahn*.py
%{python3_sitelib}/twisted/plugins/__pycache__/autobahn*.py*

%files -n python3-%{pypi_name}-doc
%doc docs README.rst

%changelog
* Wed Mar 27 2024 Bo Ren <rb01097748@alibaba-inc.com> - 23.6.2-2
- Rebuild with python3.11

* Wed Sep 20 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 23.6.2-1
- Init upstream from version 23.6.2
